@@ -3,19 +3,8 @@ from fgp.controller.client import Client
 from fgp.controller.store import Store
 from fgp.controller.reference import Reference
 from fgp.controller.event import Event
-
-
-class ApiClient:
-    _client: Client = None
-    store: Store = None
-    reference: Reference = None
-    client: Client = None
-
-    def __init__(self, url, application):
-        self._client = Client(url, application)
-        self.store = Store(self._client)
-        self.reference = Reference(self._client)
-        self.event = Event(self._client)
+from fgp.controller import ApiClient
+from fgp.cli import cli
 
 
 if __name__ == 'fgp':
