@@ -16,14 +16,15 @@ class Reference:
             reference_name: str,
             query: str,
             order_by: str=None,
+            order_dir: str='asc',
             limit: int=100,
             page: int=0
         ) -> List[Dict[str, str]]:
         if query:
-            query_parsed = urllib.parse.quote(query)
+            query_parsed = f'?{urllib.parse.quote(query)}'
         else:
             query_parsed = ""
-        res = self._client.get(route=f'{reference_name}/data/{limit}/{page}/{order_by}{query_parsed}')
+        res = self._client.get(route=f'{reference_name}/data/{limit}/{page}/{order_by}%20{order_dir}{query_parsed}')
         # data = self.parse_get_data(res)
         return res
 
